Function midi::utils::status_byte
[-] [+]
[src]
pub fn status_byte(status: u8, channel: Channel) -> u8
Calculate the status byte for a given channel no.
pub fn status_byte(status: u8, channel: Channel) -> u8
Calculate the status byte for a given channel no.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).